@@ -28,7 +28,7 @@
 #include <KUrlComboBox>
 #include <KUrlRequester>
 
-#include <libkomparediff2/diffsettings.h>
+#include <KompareDiff2/DiffSettings>
 
 DiffPage::DiffPage() : QFrame(), m_ignoreRegExpDialog(nullptr)
 {
@@ -344,4 +344,6 @@ void DiffPage::addExcludeTab()
     m_tabWidget->addTab(page, i18nc("@title:tab", "Exclude"));
 }
 
+#include "moc_diffpage.cpp"
+
 //kate: replace-tabs 0; indent-width 4; tab-width 4;
